package com.fuyuanshen.app.service;

import com.fuyuanshen.app.domain.vo.AppRoleMenuVo;
import com.fuyuanshen.app.domain.bo.AppRoleMenuBo;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * 角色和菜单关联Service接口
 *
 * @author Lion Li
 * @date 2025-06-27
 */
public interface IAppRoleMenuService {

    /**
     * 查询角色和菜单关联
     *
     * @param roleId 主键
     * @return 角色和菜单关联
     */
    AppRoleMenuVo queryById(Long roleId);

    /**
     * 分页查询角色和菜单关联列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 角色和菜单关联分页列表
     */
    TableDataInfo<AppRoleMenuVo> queryPageList(AppRoleMenuBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的角色和菜单关联列表
     *
     * @param bo 查询条件
     * @return 角色和菜单关联列表
     */
    List<AppRoleMenuVo> queryList(AppRoleMenuBo bo);

    /**
     * 新增角色和菜单关联
     *
     * @param bo 角色和菜单关联
     * @return 是否新增成功
     */
    Boolean insertByBo(AppRoleMenuBo bo);

    /**
     * 修改角色和菜单关联
     *
     * @param bo 角色和菜单关联
     * @return 是否修改成功
     */
    Boolean updateByBo(AppRoleMenuBo bo);

    /**
     * 校验并批量删除角色和菜单关联信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
